@@ -1,43 +1,27 @@
 /*
    A colorful `free' clone with graphs and such.
-
-   -- Roy Keene [200819992000] rkeene@suspend.net
-
-    Bug 230819992230: freecolor segfaults if swapping is off. (fixed,
-			reported by shammack@goldinc.com).
-   Warn 260919991600: Warning about returning a local variable fixed (
-                                 Jakob Erikson <jakov@quicknet.se>).
-  Annoy 270819990700: Made the code for the "-o" option neater.
-    Bug 270819990700: Fixed support for unknown options 
-                             (Rene <renec@zorro.pangea.ca)
-  Annoy 270819990800: Fixed display of buffed and cached memmory. 
-   				(Rene <renec@zorro.pangea.ca)
-  Annoy 270819991030: Fixed the ugly bargraph(), now its less ugly, but
-   			but still not very good.
-  Annoy 270819992100: Fixed the (less) ugly bargraph(), now it doesnt look
-                            so bad.
-Feature 161019991640: Added Total Free/Total Used to "-t" option.
-   
 */
 /*
- *  
- *  Redistribution and use in source and binary forms, with or without
- *  modification, are permitted provided that the following condition
- *  is met:
- *  1. Redistributions of source code must retain the following disclaimer,
- *     and this list of conditions.
+ * Copyright (c) 2004, 2005, 2009, 2013, 2014  Roy Keene
  * 
- *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
- *  INCLUDING, BUT NOT LIMITED TO, THE  IMPLIED WARRANTIES OF MERCHANTABILITY
- *  AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
- *  JUHA PIRKOLA OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- *  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- *  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
+ * Permission is hereby granted, free of charge, to any person obtaining
+ * a copy of this software and associated documentation files (the
+ * "Software"), to deal in the Software without restriction, including
+ * without limitation the rights to use, copy, modify, merge, publish,
+ * distribute, sublicense, and/or sell copies of the Software, and to
+ * permit persons to whom the Software is furnished to do so, subject to
+ * the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included
+ * in all copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+ * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+ * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
 
@@ -66,7 +50,7 @@ Feature 161019991640: Added Total Free/Total Used to "-t" option.
 #endif
 #define BARLEN 35
 #define HEADERLEN 14
-#define VERSION "0.9.1"
+#define VERSION "0.9.2"
 
 extern char *optarg;
 extern int optind, opterr, optopt;
